PyBaccarat: pybaccarat.playingcards Namespace Reference

PyBaccarat visit the ministry of silly walks

Classes
pybaccarat.playingcards Namespace Reference

This module is collection of classes used with playing Cards. More...

## Classes
class | Card
| The Card class represents a single playing card. More...
class | Shoe
| The Shoe class represents a playing card shoe. More...

## Detailed Description

This module is collection of classes used with playing Cards.

The Card class is the representation of a single playing card. The Shoe class is the representation of a stack of playing cards. This stack could be a single deck (such as poker), or a multi-deck deck (such as Baccarat).

To use: from playingcards import Card from playingcards import Stack

Author
  fulkg.nosp@m.l@gm.nosp@m.ail.c.nosp@m.om

Version
  0.13